@@ -16,5 +16,8 @@ class TestListen:
         scheduler.update_listen_data("key_1", "value_4")
         time.sleep(0.001)
         scheduler.stop()
-        print(scheduler.get_listen_datas())
-        print(scheduler.get_listen_data("key_1"))
+        # print(scheduler.get_listen_datas())
+        # print(scheduler.get_listen_data("key_1"))
+
+
+# TestListen().test_listen_data()
